@@ -172,7 +172,7 @@ void read_bayes_fromfile(znzFile fmdimfile, world_fmt *world,option_fmt *options
   long nnn=0;
   long t;
   long bin;
-  const long numpop = world->numpop;
+  //const long numpop = world->numpop;
   const long numpop2 = world->numpop2;
   const long np = world->numpop2 + world->bayes->mu;
   const long hc = world->options->heated_chains; 
@@ -191,10 +191,12 @@ void read_bayes_fromfile(znzFile fmdimfile, world_fmt *world,option_fmt *options
   MYREAL *autocorrelation;
   MYREAL *ess;
   boolean *done;
-  boolean recordedusem = options->usem;
+  //#ifndef MPI
+  //boolean recordedusem = options->usem;
+  //#endif
   MYREAL *oldmeans;
   //MYREAL theta;
-  boolean notusem = !world->options->usem;
+  //boolean notusem = !world->options->usem;
 #ifndef ZNZ
   FILE *mdimfile = fmdimfile;
 #else
