@@ -19,12 +19,24 @@
 Copyright 1996-2002 Peter Beerli and Joseph Felsenstein, Seattle WA
 Copyright 2003-2005 Peter Beerli, Tallahassee FL
  
+Permission is hereby granted, free of charge, to any person obtaining a copy
+of this software and associated documentation files (the "Software"), to deal
+in the Software without restriction, including without limitation the rights
+to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
+of the Software, and to permit persons to whom the Software is furnished to do
+so, subject to the following conditions:
+
+The above copyright notice and this permission notice shall be included in all copies
+or substantial portions of the Software.
+
+THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
+INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
+PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
+HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
+CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE
+OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
  
- This software is distributed free of charge for non-commercial use
- and is copyrighted. Of course, we do not guarantee that the software
- works and are not responsible for any damage you may cause or have.
- 
-$Id: laguerre.c 1891 2011-05-26 16:45:51Z beerli $
+$Id: laguerre.c 2067 2012-07-27 20:59:32Z beerli $
 */
 /* \file laguerre.c
 Calculates the Laguerre Quadrature points, used for gamma deviated site rate variation
@@ -482,14 +494,16 @@ main ()
     MYREAL *rate;
     MYREAL *probcat;
     long i;
+    long retval;
     printf ("Enter alpha, theta1,  and categs\n");
     retval = fscanf (stdin, "%lf%lf%li", &alpha, &theta1, &categs);
     rate = (MYREAL *) mycalloc (categs + 1, sizeof (MYREAL));
     probcat = (MYREAL *) mycalloc (categs + 1, sizeof (MYREAL));
     initgammacat (categs, alpha, theta1, rate, probcat);
+    printf ("Rate                   Log(prob)              Prob\n");
     for (i = 0; i < categs; i++)
     {
-        printf ("%20.20f %20.20f\n", rate[i], probcat[i]);
+      printf ("%20.20f %20.20f %20.20f\n", rate[i], probcat[i], exp(probcat[i]));
     }
     return 0;
 }
