@@ -10,9 +10,24 @@ using a Metropolis-Hastings Monte Carlo algorithm
 
     Copyright 2006 Peter Beerli, Tallahassee
 
-    This software is distributed free of charge for non-commercial use
-    and is copyrighted. Of course, we do not guarantee that the software
-    works and are not responsible for any damage you may cause or have.
+ Permission is hereby granted, free of charge, to any person obtaining
+ a copy of this software and associated documentation files (the
+ "Software"), to deal in the Software without restriction, including
+ without limitation the rights to use, copy, modify, merge, publish,
+ distribute, sublicense, and/or sell copies of the Software, and to
+ permit persons to whom the Software is furnished to do so, subject
+ to the following conditions:
+ 
+ The above copyright notice and this permission notice shall be
+ included in all copies or substantial portions of the Software.
+ 
+ THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
+ EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+ MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+ IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR
+ ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
+ CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
+ WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
 
     $Id$
@@ -210,6 +225,7 @@ print_mighist_output (FILE * out, world_fmt * world, MYREAL *sums, boolean mrca)
               {
                 meantime[sumloc * world->numpop2 + pop] += meantime[lp]/world->loci;
                 stdtime[sumloc * world->numpop2 + pop] += stdtime[lp]/world->loci;
+                mediantime[sumloc * world->numpop2 + pop] += mediantime[lp]/world->loci;
               }
           }
         // calculating the frequences over all parameters using the sums
@@ -239,7 +255,7 @@ print_mighist_output (FILE * out, world_fmt * world, MYREAL *sums, boolean mrca)
         for (pop = startpop; pop < endpop; pop++)
           {
             lp = sumloc * numpop2 + pop;
-            mediantime[lp] = -1.; //DEBUG: allvalues[pop][(long) (eventbinnum[pop]/2)]/freq[lp];
+            //mediantime[lp] = -1.; //DEBUG: allvalues[pop][(long) (eventbinnum[pop]/2)]/freq[lp];
             stdtime[lp] = sqrt(stdtime[lp]);
           }
       }
@@ -441,7 +457,7 @@ void print_event_values_list(FILE *file, long locus, duo **eventbins, MYREAL eve
     
     for(pop = 0; pop < numpop2; pop++)
       {  
-        age = 0.;
+      //xcode   age = 0.;
         if(pop < numpop)
           {
             fprintf(file,"\nLocus: %li   Parameter: %s_%li\n", locus+1, "Theta",pop+1);  
@@ -470,12 +486,12 @@ void read_event_values_fromfile(FILE *file, world_fmt *world)
   long locus;
   long pop;
   long i;
-  MYREAL age;
+//  MYREAL age;
   char *input;
   char *inptr;
   duo **eventbins;
   long *eventbinnum;
-  MYREAL eventbinsize;
+  //MYREAL eventbinsize;
   long spacer=0;
   long *allocsize;
   input = (char *) mycalloc(SUPERLINESIZE, sizeof(char));
@@ -501,16 +517,16 @@ void read_event_values_fromfile(FILE *file, world_fmt *world)
 	    error("help");
 	  pop       = atol(strsep(&inptr,"\t"))-1;
 	  i          = atol(strsep(&inptr,"\t"))-1;
-	  age        = atof(strsep(&inptr,"\t"));
-
+	  //age        = atof(strsep(&inptr,"\t"));
+      (void) strsep(&inptr,"\t");
 	  eventbins =  world->mighistloci[locus].migeventbins;
 	  eventbinnum = world->mighistloci[locus].migeventbinnum;
-	  eventbinsize = world->mighistloci[locus].eventbinsize;
+	//xcode   eventbinsize = world->mighistloci[locus].eventbinsize;
 
-	  if(i==0)
-	    {
-	      eventbinsize = 2 * age;
-	    }
+	//xcode   	  if(i==0)
+	    	//xcode   {
+	 	//xcode        eventbinsize = 2 * age;
+		//xcode       }
 	  eventbinnum[pop] = i+1;
 	  if(allocsize[spacer + pop] < eventbinnum[pop])
 	    {
