@@ -1,5 +1,29 @@
 #ifndef __MIGRATE_MPI_
 #define __MIGRATE_MPI_
+/*
+ (c) Peter Beerli 2013 Tallahassee FL
+ 
+ Permission is hereby granted, free of charge, to any person obtaining
+ a copy of this software and associated documentation files (the
+ "Software"), to deal in the Software without restriction, including
+ without limitation the rights to use, copy, modify, merge, publish,
+ distribute, sublicense, and/or sell copies of the Software, and to
+ permit persons to whom the Software is furnished to do so, subject
+ to the following conditions:
+ 
+ The above copyright notice and this permission notice shall be
+ included in all copies or substantial portions of the Software.
+ 
+ THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
+ EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+ MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+ IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR
+ ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
+ CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
+ WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+*/
+
+
 #ifdef MPI
 #ifdef POOCH
 #include "poochmpi.h"
@@ -51,6 +75,7 @@ extern int profiledone;
 #define MIGMPI_SKYLINE 7
 #define MIGMPI_TREESPACE 8
 #define MIGMPI_PLOTPLANE 9
+#define MIGMPI_PARALIO 10
 #ifdef MPI
 
 #ifndef PTHREADS
@@ -118,7 +143,7 @@ extern void unpack_bayes_buffer (MYREAL *buffer, world_fmt * world,
 
 extern void mpi_gradient_master (nr_fmt * nr, world_fmt * world, int *who);
 
-extern void mpi_maximize_worker (world_fmt * world, long kind, long rep);
+extern void mpi_maximize_worker (world_fmt * world, option_fmt *options,long kind, long rep);
 
 extern void mpi_startparam_master(world_fmt * world);
 extern void mpi_startparam_worker(world_fmt * world);
@@ -138,7 +163,7 @@ extern long get_filehandle(void *file, world_fmt *world, option_fmt *options, da
 extern void mpi_fprintf(FILE *file, const char *fmt, ...);
 extern void mpi_fprintf2(FILE *file, long filesize, const char *fmt, ...);
 #ifdef PARALIO
-extern void mpi_mdim_send(MPI_File *file, float *values, long size);
+extern void mpi_mdim_send(MPI_File *file, char *values, long size);
 #else
 extern void mpi_mdim_send(float *values, long size);
 #endif
