@@ -89,12 +89,14 @@ MYREAL waiting_M(long pop,long to,
 		 long *lineages, 
 		 MYREAL interval, 
 		 MYREAL inv_mu_rate,
-		 long numpop)
+		 long numpop,
+		 boolean usem)
 {
   long i;
   long kpop;
   MYREAL expected = 0.0;
   MYREAL line;
+  MYREAL pr = usem ? 1.0 : param[to];
   for(i=0;i<numpop; i++)
     {
       line = lineages[i];
@@ -102,9 +104,11 @@ MYREAL waiting_M(long pop,long to,
 	expected += (lineages[i] * (lineages[i]-1) * (1.0/ (param[i])) +  mig0list[i] * lineages[i]);
     }
   kpop = lineages[to];
-  expected = 1./interval - (expected - kpop * param[pop]) * inv_mu_rate ;
+  expected = 1./interval - (expected - kpop * param[pop]/pr) * inv_mu_rate ;
   if(kpop > EPSILON)
-    return expected / kpop;
+    {
+      return pr * expected / kpop;
+    }
   else
     return -9.;
 }
@@ -233,7 +237,7 @@ void calculate_expected_values(tetra **eventbins,
   //  MYREAL oldlweight = -HUGE;
 //xcode  boolean change;
   //  long p;
-
+  boolean usem = world->options->usem;
 //xcode  float lweight;
   //  float unweight;
   long i,j;
@@ -290,7 +294,7 @@ void calculate_expected_values(tetra **eventbins,
       weight1 = 1.0;
       pop = mm2m(from, to, numpop);
 
-      val = waiting_M(pop, to, world->param0,world->mig0list, lineages,interval, inv_mu_rate, numpop); 
+      val = waiting_M(pop, to, world->param0,world->mig0list, lineages,interval, inv_mu_rate, numpop, usem); 
 
 
       if(val < 0.0)
