@@ -11,10 +11,29 @@
  Peter Beerli 1996, Seattle
  beerli@fsu.edu
  
-Copyright 1996-2002 Peter Beerli and Joseph Felsenstein, Seattle WA
-Copyright 2003-2006 Peter Beerli, Tallahassee FL
+(c) 1996-2002 Peter Beerli and Joseph Felsenstein, Seattle WA
+(c) 2003-2006 Peter Beerli, Tallahassee FL
  
-$Id: tools.h 2081 2012-08-20 15:33:11Z beerli $
+ Permission is hereby granted, free of charge, to any person obtaining
+ a copy of this software and associated documentation files (the
+ "Software"), to deal in the Software without restriction, including
+ without limitation the rights to use, copy, modify, merge, publish,
+ distribute, sublicense, and/or sell copies of the Software, and to
+ permit persons to whom the Software is furnished to do so, subject
+ to the following conditions:
+ 
+ The above copyright notice and this permission notice shall be
+ included in all copies or substantial portions of the Software.
+ 
+ THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
+ EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+ MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
+ IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR
+ ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF
+ CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
+ WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+
+$Id: tools.h 2157 2013-04-16 22:27:40Z beerli $
 -------------------------------------------------------*/
 
 #include "migration.h"
@@ -96,6 +115,7 @@ extern void openfile (FILE ** fp, char *filename, char *mode, char *perm);
 #ifdef ZNZ
 extern void znzopenfile (znzFile * fp, char *filename, char *mode, int use_compressed);
 #endif
+extern void get_filename(char **store, char * value);
 extern long read_savesum (world_fmt * world, option_fmt * options,
                               data_fmt * data);
 extern void write_savesum (world_fmt * world);
